# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class PortalOwnerInfo(BaseModel):
    """
    Portal owner details.  # noqa: E501  # noqa: E501
    """
    email: Optional[StrictStr] = Field(default='', description="Owner's email address")
    first_name: Optional[StrictStr] = Field(default='', description="Owner's first name")
    last_name: Optional[StrictStr] = Field(default='', description="Owner's last name")
    __properties = ["email", "first_name", "last_name"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PortalOwnerInfo:
        """Create an instance of PortalOwnerInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PortalOwnerInfo:
        """Create an instance of PortalOwnerInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PortalOwnerInfo.parse_obj(obj)

        _obj = PortalOwnerInfo.parse_obj({
            "email": obj.get("email") if obj.get("email") is not None else '',
            "first_name": obj.get("first_name") if obj.get("first_name") is not None else '',
            "last_name": obj.get("last_name") if obj.get("last_name") is not None else ''
        })
        return _obj


